{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "d MMMM y",
    yMd => "dd-MM-y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "rw",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mbe.",
    "kab.",
    "gtu.",
    "kan.",
    "gnu.",
    "gnd.",
    "cyu.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Kuwa mbere",
    "Kuwa kabiri",
    "Kuwa gatatu",
    "Kuwa kane",
    "Kuwa gatanu",
    "Kuwa gatandatu",
    "Ku cyumweru",
  ],
  day_stand_alone_abbreviated => [
    "mbe.",
    "kab.",
    "gtu.",
    "kan.",
    "gnu.",
    "gnd.",
    "cyu.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Kuwa mbere",
    "Kuwa kabiri",
    "Kuwa gatatu",
    "Kuwa kane",
    "Kuwa gatanu",
    "Kuwa gatandatu",
    "Ku cyumweru",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kinyarwanda",
  month_format_abbreviated => [
    "mut.",
    "gas.",
    "wer.",
    "mat.",
    "gic.",
    "kam.",
    "nya.",
    "kan.",
    "nze.",
    "ukw.",
    "ugu.",
    "uku.",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Mutarama",
    "Gashyantare",
    "Werurwe",
    "Mata",
    "Gicurasi",
    "Kamena",
    "Nyakanga",
    "Kanama",
    "Nzeri",
    "Ukwakira",
    "Ugushyingo",
    "Ukuboza",
  ],
  month_stand_alone_abbreviated => [
    "mut.",
    "gas.",
    "wer.",
    "mat.",
    "gic.",
    "kam.",
    "nya.",
    "kan.",
    "nze.",
    "ukw.",
    "ugu.",
    "uku.",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Mutarama",
    "Gashyantare",
    "Werurwe",
    "Mata",
    "Gicurasi",
    "Kamena",
    "Nyakanga",
    "Kanama",
    "Nzeri",
    "Ukwakira",
    "Ugushyingo",
    "Ukuboza",
  ],
  name => "Kinyarwanda",
  native_language => "Ikinyarwanda",
  native_name => "Ikinyarwanda",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "I1",
    "I2",
    "I3",
    "I4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "igihembwe cya mbere",
    "igihembwe cya kabiri",
    "igihembwe cya gatatu",
    "igihembwe cya kane",
  ],
  quarter_stand_alone_abbreviated => [
    "I1",
    "I2",
    "I3",
    "I4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "igihembwe cya mbere",
    "igihembwe cya kabiri",
    "igihembwe cya gatatu",
    "igihembwe cya kane",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
